@@ -98,15 +98,6 @@ int     bounce_notify_service(int flags, char *service, char *queue_name,
     char   *postmaster;
     int     count;
 
-    /*
-     * If the original sender requested REQUIRETLS, return headers only, and
-     * do not enforce REQUIRETLS for the delivery status notification.
-     */
-    if ((sendopts & SOPT_REQUIRETLS_ESMTP) != 0) {
-	dsn_ret = DSN_RET_HDRS;
-	sendopts &= ~SOPT_REQUIRETLS_ESMTP;
-    }
-
     /*
      * Initialize. Open queue file, bounce log, etc.
      * 
