@@ -520,7 +520,7 @@ static int smtp_get_effective_tls_level(DSN_BUF *why, SMTP_STATE *state)
      * server first.
      */
     if (TLS_MUST_MATCH(tls->level) == 0) {
-	switch (state->enforce_requiretls) {
+	switch (state->enforce_reqtls) {
 	case SMTP_REQTLS_POLICY_ACT_ENFORCE:
 	    dsb_simple(why, "5.7.10", "REQUIRETLS Failure: sender "
 		       "requested REQUIRETLS, but the configured "
@@ -585,15 +585,15 @@ static void smtp_connect_local(SMTP_STATE *state, const char *path)
 
     /*
      * REQUIRETLS policy selection is based on the same TLS net-hop name as
-     * with certificate matching.
+     * with certificate matching. When var_reqtls_enable != 0,
+     * smtp_reqtls_policy must also be != 0.
      */
 #ifdef USE_TLS
-    if (smtp_reqtls_policy
-	&& STATE_REQTLS_IS_REQUESTED(var_requiretls_enable, state))
-	state->enforce_requiretls =
+    if (STATE_REQTLS_IS_REQUESTED(var_reqtls_enable, state))
+	state->enforce_reqtls =
 	    smtp_reqtls_policy_eval(smtp_reqtls_policy, var_myhostname);
     else
-	state->enforce_requiretls = SMTP_REQTLS_POLICY_ACT_DISABLE;
+	state->enforce_reqtls = SMTP_REQTLS_POLICY_ACT_DISABLE;
 #endif
 
     /*
@@ -1007,16 +1007,16 @@ static void smtp_connect_inet(SMTP_STATE *state, const char *nexthop,
 #endif						/* USE_TLSRPT */
 
 	/*
-	 * REQUIRETLS policy selection is based on the same next-hop domain
-	 * name without service or port, as with certificate matching.
+	 * REQUIRETLS policy selection is based on the same TLS net-hop name
+	 * as with certificate matching. When var_reqtls_enable != 0,
+	 * smtp_reqtls_policy must also be != 0.
 	 */
 #ifdef USE_TLS
-	if (smtp_reqtls_policy
-	    && STATE_REQTLS_IS_REQUESTED(var_requiretls_enable, state))
-	    state->enforce_requiretls =
+	if (STATE_REQTLS_IS_REQUESTED(var_reqtls_enable, state))
+	    state->enforce_reqtls =
 		smtp_reqtls_policy_eval(smtp_reqtls_policy, domain);
 	else
-	    state->enforce_requiretls = SMTP_REQTLS_POLICY_ACT_DISABLE;
+	    state->enforce_reqtls = SMTP_REQTLS_POLICY_ACT_DISABLE;
 #endif
 
 	/*
